@@ -14,7 +14,7 @@ pub async fn run() -> std::io::Result<()> {
     simple_logger::init_with_level(log::Level::Debug).expect("couldn't initialize logging");
 
     let conf = get_configuration(None).await.unwrap();
-    let addr = conf.leptos_options.site_addr.clone();
+    let addr = conf.leptos_options.site_addr;
 
     log::info!("serving at {addr}");
 
